@@ -21,13 +21,9 @@
 #define __LOG_REPAINT_H__
 
 gboolean log_repaint (LogviewWindow *window);
-void log_redrawdetail (LogviewWindow *window);
-void DrawLogLines (LogviewWindow *window, Log *current_log);
-void UpdateStatusArea (LogviewWindow *window);
 void handle_selection_changed_cb (GtkTreeSelection *selection, gpointer data);
 void handle_row_activation_cb (GtkTreeView *treeview, GtkTreePath *path,
 			       GtkTreeViewColumn *arg2, gpointer user_data);
-void save_rows_to_expand (LogviewWindow *window);
 
 #endif /* __LOG_REPAINT_H__ */
 
